const express = require('express')
const scraper = require('tiktok-scraper')
const he = require('he')

const app = express()

const port = process.env.PORT || 8080
const host = process.env.HOST || `http://localhost:${port}`

app.get('/user/:user', async (req, res) => {
    let user = req.params.user
    if (user && user.length != 0) {
        try {
            let feed = {
                "version": "https://jsonfeed.org/version/1",
                "title": `TikTok user @${user}`,
                "home_page_url": `https://tiktok.com/@${user}`,
                "items": []
            }
            let posts = await scraper.user(user, { number: 5, randomUa: true, noWaterMark: false })
            for (const post of posts.collector) {
                feed.items.push({
                    "id": post.id,
                    "title": `Post by @${user}`,
                    "content_html": he.encode(post.text),
                    "url": post.webVideoUrl,
                    "date_published": new Date(parseInt(post.createTime, 10) * 1000),
                    "attachments": [
                        {
                            "url": `${host}/video/${user}/${post.id}`,
                            "mime_type": "video/mp4"
                        }
                    ]
                })
            }
            res.send(feed)
        } catch (error) {
            console.log(error)
            res.status(500).send(JSON.stringify(error))
        }
    } else {
        res.status(403)
    }
})

app.get('/video/:user/:video', async (req, res) => {
    let user = req.params.user
    let video = req.params.video
    if (user && user.length != 0 && video && video.length != 0) {
        try {
            let videoMeta = await scraper.getVideoMeta(`https://www.tiktok.com/@${user}/video/${video}`, { noWaterMark: false })
            res.redirect(302, videoMeta.videoUrl)
        } catch (error) {
            console.log(error)
            res.status(500).send(JSON.stringify(error))
        }
    } else {
        res.status(403)
    }
})

app.listen(port, () => console.log(`Listening at http://localhost:${port}`))